@@ -17,10 +17,6 @@
 #import "VLC-Swift.h"
 #import "VLCSEPANotificationViewController.h"
 
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wpartial-availability"
-#import <AuthenticationServices/AuthenticationServices.h>
-
 @interface VLCDonationSEPAViewController () <VLCStripeControllerDelegate, UITextFieldDelegate>
 {
     NSNumber *_donationAmount;
@@ -54,7 +50,6 @@
     self.descriptionLabel.text = NSLocalizedString(@"DONATION_BANK_TRANSFER_LONG", nil);
 
     if (@available(iOS 10.0, *)) {
-        self.bankAccountNumberField.textContentType = UITextContentTypeCreditCardNumber;
         self.nameField.textContentType = UITextContentTypeName;
         self.emailField.textContentType = UITextContentTypeEmailAddress;
     }
@@ -300,16 +295,18 @@
 - (NSString *)removeNonDigits:(NSString *)string
     andPreserveCursorPosition:(NSUInteger *)cursorPosition
 {
+    NSUInteger originalCursorPosition = *cursorPosition;
     NSMutableString *digitsOnlyString = [NSMutableString new];
     for (NSUInteger i=0; i<[string length]; i++) {
         unichar characterToAdd = [string characterAtIndex:i];
-        NSString *stringToAdd = [NSString stringWithCharacters:&characterToAdd
-                                                        length:1];
-
-        if (i >= 2) {
-            [digitsOnlyString appendString:stringToAdd];
-        } else {
+        if (characterToAdd != ' ') {
+            NSString *stringToAdd = [NSString stringWithCharacters:&characterToAdd
+                                                            length:1];
             [digitsOnlyString appendString:[stringToAdd uppercaseString]];
+        } else {
+            if (i < originalCursorPosition) {
+                (*cursorPosition)--;
+            }
         }
     }
 
@@ -339,5 +336,3 @@
 }
 
 @end
-
-#pragma clang diagnostic pop
